@@ -1,14 +1,14 @@
-import io
-from http.client import HTTPException
+from http.client import HTTPException, IncompleteRead
 from urllib.error import HTTPError
 
-from Bio import Entrez, SeqIO
+from Bio import Entrez
 
-from .. import configuration
+from ..configuration import settings
 from ..request import Http400, RequestErrors, request
+from ..util import f_e
 
-Entrez.email = configuration.settings["EMAIL"]
-Entrez.api_key = configuration.settings.get("NCBI_API_KEY")
+Entrez.email = settings.get("EMAIL")
+Entrez.api_key = settings.get("NCBI_API_KEY")
 
 
 class ReferenceToLong(Exception):
@@ -43,7 +43,7 @@ def fetch_ncbi_databases(reference_id):
         reference_id = reference_id.rsplit(".")[0]
     try:
         handle = Entrez.egquery(term=reference_id)
-    except (IOError, HTTPError, HTTPException):
+    except (IOError, HTTPError, HTTPException) as e:
         raise ConnectionError
 
     result = Entrez.read(handle)
@@ -110,10 +110,7 @@ def fetch_genbank(reference_id, size_on=True):
     """
     reference_summary = _fetch_reference_summary(reference_id)
 
-    if (
-        size_on
-        and reference_summary["length"] > configuration.settings["MAX_FILE_SIZE"]
-    ):
+    if size_on and reference_summary["length"] > settings["MAX_FILE_SIZE"]:
         raise ReferenceToLong
     try:
         handle = Entrez.efetch(
@@ -144,13 +141,16 @@ def fetch_fasta(reference_id, db):
         if e.code == 400:
             # TODO: Check whether in the response is mentioned that the
             #  reference_id was not found.
-            raise NameError
+            raise NameError(f_e("fasta", e))
         else:
-            raise ConnectionError
-    except (IOError, HTTPException):
-        raise ConnectionError
+            raise ConnectionError(f_e("fasta", e))
+    except (IOError, HTTPException) as e:
+        raise ConnectionError(f_e("fasta", e))
     else:
-        raw_data = handle.read()
+        try:
+            raw_data = handle.read()
+        except IncompleteRead as e:
+            raw_data = e.partial.decode()
         handle.close()
         return raw_data
 
@@ -163,17 +163,17 @@ def fetch_gff3(reference_id, db, timeout=1):
 
     :returns str: gff3 content.
     """
-    url = "https://eutils.ncbi.nlm.nih.gov/sviewer/viewer.cgi"
+    url = settings["NCBI_GFF3_URL"]
     params = {"db": db, "report": "gff3", "id": reference_id}
     try:
         response = request(url=url, params=params, timeout=timeout)
-    except RequestErrors:
-        raise ConnectionError
+    except RequestErrors as e:
+        raise ConnectionError(f"(gff3) Original: {str(e)}")
     except Http400 as e:
         if "Failed to understand id" in e.response.text:
-            raise NameError
+            raise NameError(f_e("gff3", e))
         else:
-            raise ConnectionError
+            raise ConnectionError(f_e("gff3", e))
     else:
         return response
 
